Skip to contents

The input must contain only holdout rows from the calibration-selected candidate. This function cannot select a candidate or retune the protocol.

Usage

assess_stage1_holdout(
  selected_candidate,
  holdout_rows,
  manifest = stage1_benchmark_manifest()
)

Arguments

selected_candidate

candidate name returned by the calibration selector.

holdout_rows

one row per selected-candidate/seed/stratum from holdout.

manifest

canonical Stage 1 benchmark manifest.

Value

a serializable holdout report.