Learn R Programming

landscapeR (version 1.3.1)

landscapeR-package: landscapeR: A landscape simulator for R.

Description

This package is aimed at simulating categorical landscapes on actual geographical realms, starting from either empty landscapes, or landscapes provided by the user (e.g. land use maps). landscapeR allows to tweak or create landscapes while retaining a high degree of control on its features, without the hassle of specifying each location attribute. In this it differs from other tools which generate null or neutral landscape in a theoretical space. The basic algorithm currently implemented uses a simple agent style/cellular automata growth model, with no rules (apart from areas of exclusion). Outputs are raster dataset exportable to any common GIS format.

Arguments

landscapeR functions

  • makePatch creates a single patch in the landscape.

  • makeClass creates a group of patches belonging to the same class.

  • expandClass expands an existing class of patches.

  • makeLine creates a linear patch.

  • rmSingle removes single tones from patches and background.

Author

Dario Masante [aut, cre], Lora Murphy [ctb]

Details

Check out the vignette illustrating the use of landscapeR.
Also: https://github.com/dariomasante/landscapeR