Skip to contents

Displays retained finite effect evidence when available and the machine-readable reason that prevents nomination. The plot never marks or promotes an alternative component.

Usage

# S3 method for class 'ComponentAbstention'
plot(x, y, ...)

Arguments

x

a ComponentAbstention

y

ignored

...

ignored

Value

a ggplot object