Skip to contents

Shows the null distribution of the maximum absolute target effect across the complete eligible-component search. The observed maximum is marked in red and cannot alter the point ranking.

Usage

# S3 method for class 'PermutationEvidence'
plot(x, y, ...)

Arguments

x

a PermutationEvidence

y

ignored

...

ignored

Value

a ggplot object