Skip to contents

Runs decompose() with the given strategy and computes the principal angle between the recovered shared axis and the ground-truth shared axis.

Usage

recovery_benchmark(std, strategy_name = "hogsvd_averaged")

Arguments

std

StateTransitionData from synthetic_control()

strategy_name

character name registered under the "Decomposer" contract

Value

named list: angle_deg, signal_above_bbp, elapsed_sec, warnings