Sets L'Ecuyer-CMRG so parallel streams (via targets / future) are reproducible. Call once at the start of a pipeline run. Retrofitting this later is painful; it is designed in from the start.
Sets L'Ecuyer-CMRG so parallel streams (via targets / future) are reproducible. Call once at the start of a pipeline run. Retrofitting this later is painful; it is designed in from the start.