Skip to contents

This fractional design exercises all important benchmark contract branches quickly. It is intentionally incompatible with candidate selection and holdout acceptance.

Usage

stage1_development_manifest()

Value

a versioned development-only benchmark manifest.