The input must contain only holdout rows from the calibration-selected candidate. This function cannot select a candidate or retune the protocol.
Usage
assess_stage1_holdout(
selected_candidate,
holdout_rows,
manifest = stage1_benchmark_manifest()
)