Plot a component-nomination abstention
Source:R/13b-component-interpretation.R
plot.ComponentAbstention.RdDisplays retained finite effect evidence when available and the machine-readable reason that prevents nomination. The plot never marks or promotes an alternative component.
Usage
# S3 method for class 'ComponentAbstention'
plot(x, y, ...)