Plot search-aware permutation evidence
Source:R/13b-component-interpretation.R
plot.PermutationEvidence.RdShows the null distribution of the maximum absolute target effect across the complete eligible-component search. The observed maximum is marked in red and cannot alter the point ranking.
Usage
# S3 method for class 'PermutationEvidence'
plot(x, y, ...)